The Dune-MMesh Module
=====================

The Dune-MMesh Module is an implementation of the DUNE grid interface that wraps CGAL triangulations in 2D and 3D.
It is also capable to export a prescribed set of cell facets as a dim-1 interface grid and remesh the grid when moving this interface.

You find the documentation of Dune-MMesh at [dune-mmesh.readthedocs.io](https://dune-mmesh.readthedocs.io).
